@@ -30,6 +30,10 @@ def dump_json_data(json_path, data):
     with open(json_path, 'w', encoding='utf-8') as f:
         json.dump(data, f, indent="\t")
 
+def dumps_json_data(json_path, data):
+    with open(json_path, 'w', encoding='UTF-8-sig') as f:
+        f.write(json.dumps(data, ensure_ascii=False, indent = 4, sort_keys = True))
+
 def get_json_data_all(json_path):
     with open(json_path, 'r') as f:
         data =  json.load(f)
@@ -268,18 +272,20 @@ def get_embedding_for_tflite_with_label(poses, embedding, labels, side, joint, c
             pass
     return pose_data, embedding_data, label_data
 
-def get_embedding_for_tflite_with_label_taekwondo(poses, embeddingType, labels):
+def get_embedding_for_tflite_with_label_taekwondo(poses, embeddingType, labels, dimension="3d"):
     embedding_data = []
     pose_data = []
     label_data = []
     valid_idx = []
     if embeddingType != "TAEKWONDO":
-        for label, pose in zip(labels, poses):
+        for idx, (label, pose) in enumerate(zip(labels, poses)):
             try:
-                embedding_data.append(getPoseEmbeddingList(pose, embeddingType.upper()))
+                embedding_data.append(getPoseEmbeddingList(pose, embeddingType.upper(), dimension))
                 pose_data.append(pose)
                 label_data.append(label)
+                valid_idx.append(idx)
             except Exception as e:
+                print(e)
                 pass
     else:
         for idx, (label, pose) in enumerate(zip(labels[:-4], poses[:-4])):
@@ -324,7 +330,7 @@ def get_embedding_for_tflite(poses, embedding, side, joint, coord, equation):
             pass
     return pose_data, embedding_data
 
-def get_embedding_for_tflite_taekwondo(poses, embedding):
+def get_embedding_for_tflite_taekwondo(poses, embedding, labels):
     embedding_data = []
     if embedding != "TAEKWONDO":
         for label, pose in zip(labels, poses):
