@@ -4,8 +4,15 @@ import os
 #------------------------------------------------------------------------
 # Path 
 DIR_PATH = os.getcwd()
-KNN_PATH = DIR_PATH + '/data/knnData'
-SYNC_PATH = DIR_PATH + "/data/syncData"
+if DIR_PATH.split('/')[-1] == "poseAnalizer":
+    KNN_PATH = DIR_PATH + '/GymMate/data/knnData'
+    KT_LOGIC_COACHING_PATH = DIR_PATH + "/GymMate/ktLogicCoaching"
+    GYMMATE_FONT_PATH = DIR_PATH + "/GymMate/font"
+elif DIR_PATH.split('/')[-1] == "GymMate":
+    KNN_PATH = DIR_PATH + '/data/knnData'
+    KT_LOGIC_COACHING_PATH = DIR_PATH + "/ktLogicCoaching"
+    GYMMATE_FONT_PATH = DIR_PATH + "/font"
+
 DANCE_DATA_PATH = DIR_PATH + '/data/danceData'
 
 DANCE_VIDEO_PATH = DANCE_DATA_PATH + '/video'
@@ -14,24 +21,18 @@ DANCE_IMG_PATH = DANCE_DATA_PATH + '/imgs'
 DANCE_AUDIO_PATH = DANCE_DATA_PATH + '/audio'
 DANCE_AUDIO_COMMON_PATH = DANCE_AUDIO_PATH + '/common/'
 
-SYNC_STANDARD_PATH = SYNC_PATH + '/Standard'
-SYNC_COMPARE_PATH = SYNC_PATH + '/Compare'
 
-SYNC_STANDARD_PICKLE_PATH = SYNC_STANDARD_PATH + '/pickle'
-SYNC_STANDARD_IMG_PATH = SYNC_STANDARD_PATH + '/imgs'
-SYNC_COMPARE_PICKLE_PATH = SYNC_COMPARE_PATH + '/pickle'
-SYNC_COMPARE_IMG_PATH = SYNC_COMPARE_PATH + '/imgs'
-
-AUDIO_JSON_PATH = DIR_PATH + "/audio_info.json"
+AUDIO_JSON_PATH = DANCE_DATA_PATH + "/audio_info.json"
 NAS_PATH = "/Volumes/Multimedia/댄스"
 MLP_PATH_DATA = "/Volumes/FrameData/mlp/data"
 MLP_PATH = "/Volumes/FrameData/mlp"
 LSTM_PATH = "/Volumes/FrameData/lstm"
 TRANSFORMER_PATH = "/Volumes/FrameData/transformer"
-LINUX_LSTM_PATH = "/home/jinwoo/jinwoo/lstm"
+LINUX_TRANSFORMER_PATH = "/home/hnh/FrameData/transformer"
+LINUX_LSTM_PATH = "/home/hnh/FrameData/lstm"
 
 TAEKWONDO_PATH = "/Volumes/FrameData/TaeKwondo"
-TAEKWONDO_LINUX_PATH = "/home/jinwoo/jinwoo/frameData/TaeKwondo"
+TAEKWONDO_LINUX_PATH = "/home/hnh/FrameData/TaeKwondo"
 
 POSE_MEASURE_SAVE_PATH = DIR_PATH + "/poseutil/utils/poseMeasure.py"
 
@@ -354,6 +355,7 @@ BODYNOSERIGHT = "BODYNOSERIGHT"
 LOWERYANG = "LOWERYANG"
 LOWERYANGLEFT = "LOWERYANGLEFT"
 LOWERYANGRIGHT = "LOWERYANGRIGHT"
+YOLOLOWER = "YOLOLOWER"
 
 
 TAEKWONDO_EMBEDDING = [
@@ -540,8 +542,6 @@ STANDARD_JOINT_MAP = {
 
 CONTENTS = ["Weight", "Yang", "Beginner"]
 
-APP_LIST = ['test', 'gymmate']
-
 TAEKWONDO_LSTM_MAP = {
     "STANDBY" : 0 ,
     "SIDE_KICK" : 1 , 
@@ -576,4 +576,30 @@ TAEKWONDO_LABEL = [
             ]
 
 MODEL_TRANSFORMER = 'transformer'
-MODEL_LSTM = 'lstm'
\ No newline at end of file
+MODEL_LSTM = 'lstm'
+
+MP2YOLO = {
+    RIGHT_SHOULDER: 6,
+    RIGHT_ELBOW: 8,
+    RIGHT_WRIST: 10,
+    LEFT_SHOULDER: 5,
+    LEFT_ELBOW: 7,
+    LEFT_WRIST: 9,
+    RIGHT_HIP: 12,
+    RIGHT_KNEE: 14,
+    RIGHT_ANKLE: 16,
+    LEFT_HIP: 11,
+    LEFT_KNEE: 13,
+    LEFT_ANKLE: 15
+}
+
+TAEKWONDO_LSTM_MAP_REVERSE_KR = {
+    0 : "준비" ,
+    1 : "옆차기", 
+    2 : "앞차기"  ,
+    3 : "내려차기" ,
+    4 : "돌려차기" ,
+    5 : "뒤차기" ,
+    6 : "뒤후리기" ,
+    7 : "돌개차기" ,
+}
\ No newline at end of file
