@@ -4,7 +4,21 @@ from utils.const import *
 from utils.math_util import get_rotate, get_move_hand_coordinate
 
 #cv component
-def draw_landmarks(image, origin_poses, origin_hands, width, height, x_degree=0, y_degree=0):
+def draw_landmarks_with_color(image, poses, width, height, color):
+    try:
+        for k, v in RIGHT_LINK:
+            cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), color, 4)
+        for k, v in LEFT_LINK:
+            cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), color, 4)
+        for k, v in CENTER_LINK:
+            cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (255, 255, 255), 4)
+        for k in BODY_DOT:
+            cv2.circle(image, list(map(int, (poses[k].x * width, poses[k].y * height))), 4, (0, 0, 255), -1)
+    except Exception as e:
+        print(e)
+        pass
+
+def draw_landmarks(image, origin_poses, origin_hands, width, height, thickenss=4, x_degree=0, y_degree=0):
     poses = []
     x_center = (origin_poses[LEFT_HIP].x + origin_poses[RIGHT_HIP].x)/2
     y_center = (origin_poses[LEFT_HIP].y + origin_poses[RIGHT_HIP].y)/2
@@ -27,24 +41,24 @@ def draw_landmarks(image, origin_poses, origin_hands, width, height, x_degree=0,
     try:
         if poses[11].z < poses[12].z:
             for k, v in RIGHT_LINK:
-                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (0, 255, 0), 4)
+                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (0, 255, 0), thickenss)
             for k, v in LEFT_LINK:
-                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (255, 0, 0), 4)
+                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (255, 0, 0), thickenss)
         else:
             for k, v in LEFT_LINK:
-                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (255, 0, 0), 4)
+                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (255, 0, 0), thickenss)
             for k, v in RIGHT_LINK:
-                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (0, 255, 0), 4)
+                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (0, 255, 0), thickenss)
 
         
         for k, v in CENTER_LINK:
-            cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (255, 255, 255), 4)
+            cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (255, 255, 255), thickenss)
         for k in BODY_DOT:
-            cv2.circle(image, list(map(int, (poses[k].x * width, poses[k].y * height))), 4, (0, 0, 255), -1)
+            cv2.circle(image, list(map(int, (poses[k].x * width, poses[k].y * height))), thickenss, (0, 0, 255), -1)
         
         for hand in hands:
             for k, v in HAND:
-                cv2.line(image, list(map(int, (hand[k].x * width, hand[k].y * height))), list(map(int, (hand[v].x * width, hand[v].y * height))), (0, 255, 255), 4)
+                cv2.line(image, list(map(int, (hand[k].x * width, hand[k].y * height))), list(map(int, (hand[v].x * width, hand[v].y * height))), (0, 255, 255), thickenss)
             for k in HAND_DOT:
                 cv2.circle(image, list(map(int, (hand[k].x * width, hand[k].y * height))), 4, (0, 0, 255), -1)
     except Exception as e:
