@@ -82,13 +82,14 @@ def getPoseEmbedding(landmarks, exerciseType):
     normalizedLandmarks = normalize(landmarks)
     return getEmbedding(normalizedLandmarks, exerciseType)
 
-def getPoseEmbeddingList(landmarks, exerciseType):
+def getPoseEmbeddingList(landmarks, exerciseType, dimension="3d"):
     embeddings = getPoseEmbedding(landmarks, exerciseType)
     result = []
     for embedding in embeddings:
         result.append(embedding.x)
         result.append(embedding.y)
-        result.append(embedding.z)
+        if dimension == "3d":
+            result.append(embedding.z)
     return result
 
 
@@ -233,6 +234,20 @@ def getEmbedding(lm, exerciseType):
             subtract(lm[RIGHT_HIP], lm[RIGHT_KNEE]),
             subtract(lm[LEFT_KNEE], lm[RIGHT_KNEE]), 
             subtract(lm[LEFT_ANKLE], lm[RIGHT_ANKLE])]
+    elif exerciseType == YOLOLOWER:
+        embedding = [
+            subtract(lm[LEFT_KNEE], lm[LEFT_ANKLE]), 
+            subtract(lm[RIGHT_KNEE], lm[RIGHT_ANKLE]),
+            subtract(lm[LEFT_SHOULDER], lm[LEFT_ANKLE]), 
+            subtract(lm[RIGHT_SHOULDER], lm[RIGHT_ANKLE]),
+            subtract(lm[LEFT_SHOULDER], lm[LEFT_KNEE]), 
+            subtract(lm[RIGHT_SHOULDER], lm[RIGHT_KNEE]),
+            subtract(lm[LEFT_HIP], lm[LEFT_ANKLE]), 
+            subtract(lm[RIGHT_HIP], lm[RIGHT_ANKLE]), 
+            subtract(lm[LEFT_HIP], lm[LEFT_KNEE]), 
+            subtract(lm[RIGHT_HIP], lm[RIGHT_KNEE]),
+            subtract(lm[LEFT_KNEE], lm[RIGHT_KNEE]), 
+            subtract(lm[LEFT_ANKLE], lm[RIGHT_ANKLE])]
     elif exerciseType == FULLLEFT:
         embedding = [subtract(lm[LEFT_HIP], lm[LEFT_SHOULDER]),
                      subtract(lm[LEFT_SHOULDER], lm[LEFT_ELBOW]),
