@@ -1,8 +1,8 @@
-from PyQt5.QtGui import QFont, QIcon
-from PyQt5.QtWidgets import QTableWidgetItem
-from PyQt5.QtCore import *
-from PyQt5.QtWidgets import QSlider, QPushButton
-from PyQt5 import QtWidgets
+from PyQt6.QtGui import QFont, QIcon
+from PyQt6.QtWidgets import QTableWidgetItem
+from PyQt6.QtCore import *
+from PyQt6.QtWidgets import QSlider, QPushButton
+from PyQt6 import QtWidgets
 
 def listViewSetup(list_widget, row, connect):
     for i in row:
@@ -69,7 +69,7 @@ def tableSetup(table, rows, cols, data=None, row_header=None, col_header=None):
 def comboBoxSetup(combo_box, item_list, connect):
     for item in item_list:
         combo_box.addItem(item)
-    combo_box.activated[str].connect(connect)
+    combo_box.activated.connect(connect)
 
 def easySliderSetup(sd, connect, range=(0,100), step=1, defalut_value = 0):
     sd.setRange(range[0], range[1])
@@ -82,26 +82,55 @@ class PlaySliderBar(QtWidgets.QMainWindow):
         QtWidgets.QMainWindow.__init__(self)
         self.slider = QSlider(Qt.Horizontal, self)
         self.pb_play = QPushButton('', self)
+        self.pb_fast = QPushButton('', self)
+        self.pb_slow = QPushButton('', self)
+        self.pb_fast.setIcon(QIcon('imgs/fast.png'))
+        self.pb_slow.setIcon(QIcon('imgs/slow.png'))
         self.pb_play.setIcon(QIcon('imgs/play.png'))
+
         self.pb_play_is_clicked = False
         self.cur_frame_num = 0
         self.load_finished_frame_num = 0
+        self.defalut_interval = 20
         self.timer = QTimer()
-        self.timer.setInterval(1)
+        self.timer.setInterval(self.defalut_interval)
         self.timer.timeout.connect(self.playOnChangedFrameNum)
         self.setUpUI()
+
+    def setTimer(self):
+        self.timer = QTimer()
+        self.timer.setInterval(self.defalut_interval)
+        self.timer.timeout.connect(self.playOnChangedFrameNum)
     
     def setUpUI(self):
         self.main_widget = QtWidgets.QWidget(self)
         self.mainLayout = QtWidgets.QGridLayout(self.main_widget)
         easySliderSetup(self.slider, self.onChangedFrameNum)
         self.pb_play.clicked.connect(self.onClickedPlayBtn)
+        self.pb_fast.clicked.connect(self.onClickedFastBtn)
+        self.pb_slow.clicked.connect(self.onClickedSlowBtn)
 
-        self.mainLayout.addWidget(self.pb_play, 0, 0, 1, 1)
-        self.mainLayout.addWidget(self.slider, 0, 1, 1, 1)
+        self.mainLayout.addWidget(self.pb_slow, 0, 0, 1, 1)
+        self.mainLayout.addWidget(self.pb_play, 0, 1, 1, 1)
+        self.mainLayout.addWidget(self.pb_fast, 0, 2, 1, 1)
+        self.mainLayout.addWidget(self.slider, 0, 3, 1, 1)
         self.main_widget.setFocus()
         self.setCentralWidget(self.main_widget)
     
+    def onClickedSlowBtn(self):
+        self.defalut_interval += 20
+        if self.defalut_interval >= 200:
+            self.defalut_interval = 200
+        self.timer.setInterval(self.defalut_interval)
+
+    def onClickedFastBtn(self):
+        self.defalut_interval -= 20
+        if self.defalut_interval < 0:
+            self.defalut_interval = 0
+            self.timer.setInterval(1)
+        else:
+            self.timer.setInterval(self.defalut_interval)
+
     def onClickedPlayBtn(self):
         if self.pb_play_is_clicked:
             self.pb_play.setIcon(QIcon('imgs/play.png'))
